% Lag box plot av snødybde og snøtetthet for Rybekken og Sylsjødammen
% INPUT: .txt-filer med observasjoner fra Rybekken og Sylsjødammen med
% årstall, snødybde, snøtetthet og SWE i henholdsvis første, andre, tredje og fjerde kolonne
clc, clear all, close all

% Last inn data
ry = load('rybekken.txt');
sy = load('sylsjodammen.txt');

ry_depth = ry(:,2);
ry_density = ry(:,3);
ry_SWE = ry(:,4);
sy_depth = sy(:,2);
sy_density = sy(:,3);
sy_SWE = sy(:,4);

% Sett sammen vektorene
depth = [ry_depth; sy_depth];
density = [ry_density; sy_density];
SWE = [ry_SWE; sy_SWE];

% Lagre antall observasjoner
ry_num = length(ry);
sy_num = length(sy);

% Opprett grupperingsvariabel
grp = [repmat('Rybekken    ',ry_num,1); repmat('Sylsjodammen',sy_num,1)];

% Lag box plot
figure(1), set(gcf,'Color','White')

subplot(1,3,1), hold on
title('Dybde','FontWeight','bold')
boxplot(depth,grp)
ylabel('{Dybde (cm)}')
hold off

subplot(1,3,2), hold on
title('Tetthet','FontWeight','bold')
boxplot(density,grp)
ylabel('{Tetthet (g/cm^3)}')
hold off

subplot(1,3,3), hold on
title('SWE','FontWeight','bold')
boxplot(SWE,grp)
ylabel('{SWE (cm)}')
hold off

% Lager ett boxplott for hvert år ved å bruke årstall som
% grupperingsvariabel

ry_year = ry(:,1);
sy_year = sy(:,1);

figure(2) % Åpne figurvindu

subplot(2,2,1) % Øverst, venstre
boxplot(ry_depth,ry_year,'plotstyle','compact','orientation','horizontal')
set(gca,'YDir','reverse'); % Snu rekkefølgen slik at 1976 kommer øverst og 2006 nederst
title('{Dybde, Rybekken}','FontWeight','bold')
xlabel('{Dybde (cm)}')

subplot(2,2,2) % Øverst, høyre
boxplot(ry_density,ry_year,'plotstyle','compact','orientation','horizontal')
set(gca,'YDir','reverse');
title('{Tetthet, Rybekken}','FontWeight','bold')
xlabel('{Tetthet (g/cm^3)}')

subplot(2,2,3) % Nederst, venstre
boxplot(sy_depth,sy_year,'plotstyle','compact','orientation','horizontal')
set(gca,'YDir','reverse');
title('{Dybde, Sylsjodammen}','FontWeight','bold')
xlabel('{Dybde (cm)}')

subplot(2,2,4) % Nederst, høyre
boxplot(sy_density,sy_year,'plotstyle','compact','orientation','horizontal')
set(gca,'YDir','reverse');
title('{Tetthet, Sylsjodammen}','FontWeight','bold')
xlabel('{Tetthet (g/cm^3)}')
